/*
 Screamer Mirror / Halloween decor

 This code is to be used with an ESP-32 to play the scream via Bluetooth
 Find the full project at my instructables
 https://www.instructables.com/member/CaveMad/
*/
// ==> complie with Partition Scheme - Huge APP !

#include "Adafruit_NeoPixel.h"
#include "BluetoothA2DPSource.h"
#include "scream16bit.h"

//Define pins for the HC-SR04
const int trigPin = 32;
const int echoPin = 35;

//Define sound speed in cm/uS
#define SOUND_SPEED 0.034
#define CM_TO_INCH 0.393701

long duration;
float distanceCm;
float distanceInch;

#define STRIP_1_PIN    27  //Define the pin for the first strip
#define STRIP_2_PIN    14  //Define the pin for the second strip
#define LED_COUNT  4  //Number of LEDs
#define BRIGHTNESS 255  //NeoPixel brightness, 0 (min) to 255 (max)

Adafruit_NeoPixel strip1(LED_COUNT, STRIP_1_PIN, NEO_GRB + NEO_KHZ800);
Adafruit_NeoPixel strip2(LED_COUNT, STRIP_2_PIN, NEO_GRB + NEO_KHZ800);

BluetoothA2DPSource a2dp_source; //Set Bluetooth config
SoundData *data = new TwoChannelSoundData((Frame*)rawData,rawData_len/4); //Set audio config (16bit)

void setup() {
  pinMode(trigPin, OUTPUT); // Sets the trigPin as an Output
  pinMode(echoPin, INPUT); // Sets the echoPin as an Input
 
  strip1.begin();
  strip2.begin();

  // Set brightness
  strip1.setBrightness(BRIGHTNESS);
  strip2.setBrightness(BRIGHTNESS);

  a2dp_source.start("BT Device"); //Set your Bluetooth speaker
  a2dp_source.set_volume(80); //Set audio volume
}

void loop() {
  //Clears the trigPin
  digitalWrite(trigPin, LOW);
  delayMicroseconds(2);
  //Sets the trigPin on HIGH state for 10 micro seconds
  digitalWrite(trigPin, HIGH);
  delayMicroseconds(10);
  digitalWrite(trigPin, LOW);
  
  //Reads the echoPin, returns the sound wave travel time in microseconds
  duration = pulseIn(echoPin, HIGH);
  
  // Calculate the distance
  distanceCm = duration * SOUND_SPEED/2;
  
  //Convert to inches
  distanceInch = distanceCm * CM_TO_INCH;
  delay(100);

   if (distanceCm <=100){ //Set the trigger distance (on cm)
    
    //Set the color of each led to white
    strip1.setPixelColor(0, strip1.Color(255,255,255));
    strip1.setPixelColor(1, strip1.Color(255,255,255));
    strip1.setPixelColor(2, strip1.Color(255,255,255));
    strip1.setPixelColor(3, strip1.Color(255,255,255));
    
    strip2.setPixelColor(0, strip2.Color(255,255,255));
    strip2.setPixelColor(1, strip2.Color(255,255,255));
    strip2.setPixelColor(2, strip2.Color(255,255,255));
    strip2.setPixelColor(3, strip2.Color(255,255,255));

    //Show the updated colors
    strip1.show();
    strip2.show();
   
    a2dp_source.write_data(data); //play the scream via Bluetooth
    delay(1000);

    //Set the color of each led to blue
    strip1.setPixelColor(0, strip1.Color(255,0,0));
    strip1.setPixelColor(1, strip1.Color(255,0,0));
    strip1.setPixelColor(2, strip1.Color(255,0,0));
    strip1.setPixelColor(3, strip1.Color(255,0,0));
    
    strip2.setPixelColor(0, strip2.Color(255,0,0));
    strip2.setPixelColor(1, strip2.Color(255,0,0));
    strip2.setPixelColor(2, strip2.Color(255,0,0));
    strip2.setPixelColor(3, strip2.Color(255,0,0));

    //Show the updated colors
    strip1.show();
    strip2.show();
    
    delay(500);

    //Set the color of each led to red
    strip1.setPixelColor(0, strip1.Color(0,0,255));
    strip1.setPixelColor(1, strip1.Color(0,0,255));
    strip1.setPixelColor(2, strip1.Color(0,0,255));
    strip1.setPixelColor(3, strip1.Color(0,0,255));
    
    strip2.setPixelColor(0, strip2.Color(0,0,255));
    strip2.setPixelColor(1, strip2.Color(0,0,255));
    strip2.setPixelColor(2, strip2.Color(0,0,255));
    strip2.setPixelColor(3, strip2.Color(0,0,255));

    //Show the updated colors
    strip1.show();
    strip2.show();
   
    delay(500);
    
    //Set the color of each led to blue
    strip1.setPixelColor(0, strip1.Color(255,0,0));
    strip1.setPixelColor(1, strip1.Color(255,0,0));
    strip1.setPixelColor(2, strip1.Color(255,0,0));
    strip1.setPixelColor(3, strip1.Color(255,0,0));
    
    strip2.setPixelColor(0, strip2.Color(255,0,0));
    strip2.setPixelColor(1, strip2.Color(255,0,0));
    strip2.setPixelColor(2, strip2.Color(255,0,0));
    strip2.setPixelColor(3, strip2.Color(255,0,0));

    //Show the updated colors
    strip1.show();
    strip2.show();
    
    delay(500);
    
    //Set the color of each led to red
    strip1.setPixelColor(0, strip1.Color(0,0,255));
    strip1.setPixelColor(1, strip1.Color(0,0,255));
    strip1.setPixelColor(2, strip1.Color(0,0,255));
    strip1.setPixelColor(3, strip1.Color(0,0,255));
    
    strip2.setPixelColor(0, strip2.Color(0,0,255));
    strip2.setPixelColor(1, strip2.Color(0,0,255));
    strip2.setPixelColor(2, strip2.Color(0,0,255));
    strip2.setPixelColor(3, strip2.Color(0,0,255));

    //Show the updated colors
    strip1.show();
    strip2.show();
    
    delay(500);
    
    //Set the color of each led to white
    strip1.setPixelColor(0, strip1.Color(255,255,255));
    strip1.setPixelColor(1, strip1.Color(255,255,255));
    strip1.setPixelColor(2, strip1.Color(255,255,255));
    strip1.setPixelColor(3, strip1.Color(255,255,255));
    
    strip2.setPixelColor(0, strip2.Color(255,255,255));
    strip2.setPixelColor(1, strip2.Color(255,255,255));
    strip2.setPixelColor(2, strip2.Color(255,255,255));
    strip2.setPixelColor(3, strip2.Color(255,255,255));

    //Show the updated colors
    strip1.show();
    strip2.show();
    
    delay(2000);

    //Set the strips to clear
    strip1.clear();
    strip2.clear();

    //Show the update
    strip1.show();
    strip2.show();
  }
}
